==> openui5-1.120.10.jar: META-INF/resources/webjars/openui5/1.120.10/resources/sap/ui/fl/apply/_internal/appVariant/DescriptorChangeTypes-dbg.js <==
/*!
 * OpenUI5
 * (c) Copyright 2009-2024 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */

sap.ui.define([
], function(
) {
	"use strict";

	return {
		getChangeTypes() {
			return [
				"appdescr_ovp_addNewCard",
				"appdescr_ovp_removeCard",
				"appdescr_ovp_changeCard",
				"appdescr_app_addNewInbound",
				"appdescr_app_changeInbound",
				"appdescr_app_removeInbound",
				"appdescr_app_removeAllInboundsExceptOne",
				"appdescr_app_addNewOutbound",
				"appdescr_app_changeOutbound",
				"appdescr_app_removeOutbound",
				"appdescr_app_addNewDataSource",
				"appdescr_app_changeDataSource",
				"appdescr_app_removeDataSource",
				"appdescr_app_addAnnotationsToOData",
				"appdescr_app_addTechnicalAttributes",
				"appdescr_app_removeTechnicalAttributes",
				"appdescr_app_setTitle",
				"appdescr_app_setSubTitle",
				"appdescr_app_setShortTitle",
				"appdescr_app_setDescription",
				"appdescr_app_setInfo",
				"appdescr_app_setDestination",
				"appdescr_app_setKeywords",
				"appdescr_app_setAch",
				"appdescr_app_addCdsViews",
				"appdescr_app_removeCdsViews",
				"appdescr_flp_setConfig",
				"appdescr_ui5_addNewModelEnhanceWith",
				"appdescr_ui5_removeModel",
				"appdescr_ui5_replaceComponentUsage",
				"appdescr_ui5_setMinUI5Version",
				"appdescr_smb_addNamespace",
				"appdescr_smb_changeNamespace",
				"appdescr_ui_generic_app_setMainPage",
				"appdescr_ui_setIcon",
				"appdescr_ui_setDeviceTypes",
				"appdescr_ui5_addLibraries",
				"appdescr_ui5_addNewModel",
				"appdescr_app_addAnnotationsToOData",
				"appdescr_ui5_addComponentUsages",
				"appdescr_ui5_setFlexExtensionPointEnabled",
				"appdescr_url_setUri",
				"appdescr_fiori_setRegistrationIds",
				"appdescr_card",
				"appdescr_card_designtime",
				"appdescr_fiori_setAbstract",
				"appdescr_fe_changePageConfiguration"
			];
		},
		getCondensableChangeTypes() {
			return [
				"appdescr_app_setTitle",
				"appdescr_app_setInfo",
				"appdescr_app_setShortTitle",
				"appdescr_app_setSubTitle",
				"appdescr_app_setDescription",
				"appdescr_app_setDestination",
				"appdescr_app_setKeywords",
				"appdescr_app_setAch",
				"appdescr_ui_setIcon",
				"appdescr_ui_setDeviceTypes",
				"appdescr_ui_setIcon",
				"appdescr_ui_setDeviceTypes",
				"appdescr_fiori_setRegistrationIds",
				"appdescr_smb_changeNamespace"
			];
		}
	};
});

==> openui5-1.120.22.jar: META-INF/resources/webjars/openui5/1.120.22/resources/sap/ui/fl/apply/_internal/appVariant/DescriptorChangeTypes-dbg.js <==
/*!
 * OpenUI5
 * (c) Copyright 2009-2024 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */

sap.ui.define([
], function(
) {
	"use strict";

	return {
		getChangeTypes() {
			return [
				"appdescr_ovp_addNewCard",
				"appdescr_ovp_removeCard",
				"appdescr_ovp_changeCard",
				"appdescr_app_addNewInbound",
				"appdescr_app_changeInbound",
				"appdescr_app_removeInbound",
				"appdescr_app_removeAllInboundsExceptOne",
				"appdescr_app_addNewOutbound",
				"appdescr_app_changeOutbound",
				"appdescr_app_removeOutbound",
				"appdescr_app_addNewDataSource",
				"appdescr_app_changeDataSource",
				"appdescr_app_removeDataSource",
				"appdescr_app_addAnnotationsToOData",
				"appdescr_app_addTechnicalAttributes",
				"appdescr_app_removeTechnicalAttributes",
				"appdescr_app_setTitle",
				"appdescr_app_setSubTitle",
				"appdescr_app_setShortTitle",
				"appdescr_app_setDescription",
				"appdescr_app_setInfo",
				"appdescr_app_setDestination",
				"appdescr_app_setKeywords",
				"appdescr_app_setAch",
				"appdescr_app_addCdsViews",
				"appdescr_app_removeCdsViews",
				"appdescr_flp_setConfig",
				"appdescr_ui5_addNewModelEnhanceWith",
				"appdescr_ui5_removeModel",
				"appdescr_ui5_replaceComponentUsage",
				"appdescr_ui5_setMinUI5Version",
				"appdescr_smb_addNamespace",
				"appdescr_smb_changeNamespace",
				"appdescr_ui_generic_app_setMainPage",
				"appdescr_ui_setIcon",
				"appdescr_ui_setDeviceTypes",
				"appdescr_ui5_addLibraries",
				"appdescr_ui5_addNewModel",
				"appdescr_app_addAnnotationsToOData",
				"appdescr_ui5_addComponentUsages",
				"appdescr_ui5_setFlexExtensionPointEnabled",
				"appdescr_url_setUri",
				"appdescr_fiori_setRegistrationIds",
				"appdescr_card",
				"appdescr_card_designtime",
				"appdescr_fiori_setAbstract",
				"appdescr_fe_changePageConfiguration",
				"appdescr_ui_generic_app_addNewObjectPage",
				"appdescr_ui_generic_app_changePageConfiguration"
			];
		},
		getCondensableChangeTypes() {
			return [
				"appdescr_app_setTitle",
				"appdescr_app_setInfo",
				"appdescr_app_setShortTitle",
				"appdescr_app_setSubTitle",
				"appdescr_app_setDescription",
				"appdescr_app_setDestination",
				"appdescr_app_setKeywords",
				"appdescr_app_setAch",
				"appdescr_ui_setIcon",
				"appdescr_ui_setDeviceTypes",
				"appdescr_ui_setIcon",
				"appdescr_ui_setDeviceTypes",
				"appdescr_fiori_setRegistrationIds",
				"appdescr_smb_changeNamespace"
			];
		}
	};
});
